import React, {useState, useEffect, useRef} from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames';
import {mapToCssModules} from './Shared/helper.js';
import CCarouselItem from './CCarouselItem';

//component - CoreUI / CCarouselCustom

export const Context = React.createContext({});

const CCarouselCustom = props=>{

  const {
    className,
    cssModule,
    slide,
  } = props;

  const [direction, setDirection] = useState("right");
  const [indicatorClicked, setIndicatorClicked] = useState(false);

  const fields = useRef({lastProps: null}).current;

  /*
  const getChildContext = ()=>{
    return { direction: direction };
  }
  */

  const setInterval = (properties = props)=>{
    // make sure not to have multiple intervals going...
    clearInterval();
    if (properties.interval) {
      fields.cycleInterval = window.setInterval(() => {
        properties.next();
      }, parseInt(properties.interval, 10));
    }
  }

  const clearInterval = ()=>{
    window.clearInterval(fields.cycleInterval);
  }

  const hoverStart = (...args)=>{
    if (props.pause === 'hover') {
      clearInterval();
    }
    if (props.mouseEnter) {
      props.mouseEnter(...args);
    }
  }

  const hoverEnd = (...args)=>{
    if (props.pause === 'hover') {
      setInterval();
    }
    if (props.mouseLeave) {
      props.mouseLeave(...args);
    }
  }

  const handleKeyPress = (e)=>{
    if (props.keyboard) {
      if (e.keyCode === 37) {
        props.previous();
      } else if (e.keyCode === 39) {
        props.next();
      }
    }
  }

  const renderItems = (carouselItems, className)=>{
    const {slide} = props;
    return (
      <div role="listbox" className={className}>
        {carouselItems.map((item, index) => {
          const isIn = (index === props.activeIndex);
          return React.cloneElement(item, {
            in: isIn,
            slide: slide,
          });
        })}
      </div>
    );
  }

  const setState = (oVal, nVal, setF)=>{
    if (nVal===oVal)
      return;
    setF(nVal);
  }

  //effect

  useEffect(() => {
    // Set up the cycle
    if (props.ride === 'carousel') {
      setInterval();
    }
    // TODO: move this to the specific carousel like bootstrap. Currently it will trigger ALL carousels on the page.
    document.addEventListener('keyup', handleKeyPress);
    fields._handleKeyPress = handleKeyPress;
    return function cleanup() {
      clearInterval();
      document.removeEventListener('keyup', fields._handleKeyPress);
    };
  },
  []);

  //save last state
  useEffect(() => {
    //fields.lastProps = {...props};
    if (fields.wrappedOnClickFunc){
      fields.wrappedOnClickFunc();
      setIndicatorClicked(false);
      fields.wrappedOnClickFunc = null;
    }
  });

  //render

  /*
  componentWillReceiveProps(nextProps) {
    this.setInterval(nextProps);
    // Calculate the direction to turn
    if (this.props.activeIndex + 1 === nextProps.activeIndex) {
      this.setState({ direction: 'right' });
    } else if (this.props.activeIndex - 1 === nextProps.activeIndex) {
      this.setState({ direction: 'left' });
    } else if (this.props.activeIndex > nextProps.activeIndex) {
      this.setState({ direction: this.state.indicatorClicked ? 'left' : 'right' });
    } else if (this.props.activeIndex !== nextProps.activeIndex) {
      this.setState({ direction: this.state.indicatorClicked ? 'right' : 'left' });
    }
    this.setState({ indicatorClicked: false });
  }
  */

  setInterval(props);
  if (fields.lastProps){
    // Calculate the direction to turn
    if (fields.lastProps.activeIndex + 1 === props.activeIndex) {
      setState(direction, "right", setDirection);
    } else if (fields.lastProps.activeIndex - 1 === props.activeIndex) {
      setState(direction, "left", setDirection);
    } else if (fields.lastProps.activeIndex > props.activeIndex) {
      setState(direction, indicatorClicked ? "left" : "right", setDirection);
    } else if (fields.lastProps.activeIndex !== props.activeIndex) {
      setState(direction, indicatorClicked ? "right" : "left", setDirection);
    }
    //setIndicatorClicked(false);
    setState(indicatorClicked, false, setIndicatorClicked);
  }

  fields.lastProps = props;

  const outerClasses = mapToCssModules(classNames(
    className,
    'carousel',
    slide && 'slide'
  ), cssModule);
  const innerClasses = mapToCssModules(classNames(
    'carousel-inner'
  ), cssModule);

  // filter out booleans, null, or undefined
  const children = props.children.filter(child => child !== null && child !== undefined && typeof child !== 'boolean');

  const slidesOnly = children.every(child => child.type === CCarouselItem);

  // Rendering only slides
  if (slidesOnly) {
    return (
      <Context.Provider value={{direction: direction}}>
        <div className={outerClasses} onMouseEnter={hoverStart} onMouseLeave={hoverEnd}>
          {renderItems(children, innerClasses)}
        </div>
      </Context.Provider>
    );
  }

  // Rendering slides and controls
  if (children[0] instanceof Array) {
    const carouselItems = children[0];
    const controlLeft = children[1];
    const controlRight = children[2];

    return (
      <Context.Provider value={{direction: direction}}>
        <div className={outerClasses} onMouseEnter={hoverStart} onMouseLeave={hoverEnd}>
          {renderItems(carouselItems, innerClasses)}
          {controlLeft}
          {controlRight}
        </div>
      </Context.Provider>
    );
  }

  // Rendering indicators, slides and controls
  const indicators = children[0];
  const wrappedOnClick = (e) => {
    if (typeof indicators.props.onClickHandler === 'function') {
      //this.setState({ indicatorClicked: true }, () => indicators.props.onClickHandler(e));
      fields.wrappedOnClickFunc = ()=>indicators.props.onClickHandler(e);
      setIndicatorClicked(true);
    }
  };

  const wrappedIndicators = React.cloneElement(indicators, { onClickHandler: wrappedOnClick });
  const carouselItems = children[1];
  const controlLeft = children[2];
  const controlRight = children[3];

  return (
    <Context.Provider value={{direction: direction}}>
      <div className={outerClasses} onMouseEnter={hoverStart} onMouseLeave={hoverEnd}>
        {wrappedIndicators}
        {renderItems(carouselItems, innerClasses)}
        {controlLeft}
        {controlRight}
      </div>
    </Context.Provider>
  );

}

CCarouselCustom.propTypes = {
  cssModule: PropTypes.object,
  className: PropTypes.string,
  // the current active slide of the carousel
  activeIndex: PropTypes.number,
  // a function which should advance the carousel to the next slide (via activeIndex)
  next: PropTypes.func.isRequired,
  // a function which should advance the carousel to the previous slide (via activeIndex)
  previous: PropTypes.func.isRequired,
  // controls if the left and right arrow keys should control the carousel
  keyboard: PropTypes.bool,
  /* If set to "hover", pauses the cycling of the carousel on mouseenter and resumes the cycling of the carousel on
   * mouseleave. If set to false, hovering over the carousel won't pause it. (default: "hover")
   */
  pause: PropTypes.oneOf(['hover', false]),
  // Autoplays the carousel after the user manually cycles the first item. If "carousel", autoplays the carousel on load.
  // This is how bootstrap defines it... I would prefer a bool named autoplay or something...
  ride: PropTypes.oneOf(['carousel']),
  // the interval at which the carousel automatically cycles (default: 5000)
  // eslint-disable-next-line react/no-unused-prop-types
  interval: PropTypes.oneOfType([
    PropTypes.number,
    PropTypes.string,
    PropTypes.bool,
  ]),
  children: PropTypes.array,
  // called when the mouse enters the Carousel
  mouseEnter: PropTypes.func,
  // called when the mouse exits the Carousel
  mouseLeave: PropTypes.func,
  // controls whether the slide animation on the Carousel works or not
  slide: PropTypes.bool
};

CCarouselCustom.defaultProps = {
  interval: 5000,
  pause: 'hover',
  keyboard: true,
  slide: true,
};

/*
CCarouselCustom.childContextTypes = {
  direction: PropTypes.string
};
*/

export default CCarouselCustom;
